==> moodle-1.4.3-pgsql.tgz: moodle/lang/de/wiki.php <==
<?PHP // $Id$ 
      // wiki.php - created with Moodle 1.4 aiming-for-beta-soon (2004082200)


$string['action'] = '--- Aktion ---';
$string['administration'] = 'Administration';
$string['allowremovepages'] = 'Erlaubt das Entfernen von Seiten';
$string['allowrevertchanges'] = 'Erlaubt  das Aufheben einer Menge von nderungen';
$string['allowsetpage'] = 'Erlaubt das Markieren von Seiten';
$string['allowstrippages'] = 'Erlaubt das Zerlegen von Seiten';
$string['attachments'] = 'Seitenergnzungen';
$string['author'] = 'Autor/in';
$string['authorfieldpattern'] = 'Autor/in anzeigen ??';
$string['authorfieldpatternerror'] = 'Geben Sie bitte eine/n Autor/in an.';
$string['backlinks'] = 'Link zur Herkunftsseite';
$string['binimgtoolarge'] = 'Bilddatei ist zu gro!';
$string['binnoimg'] = 'Dieses Dateiformat kann nicht verarbeitet werden!';
$string['browse'] = 'Durchsuchen';
$string['canceledit'] = 'Abbrechen';
$string['cannotchangepage'] = 'Diese Seite kann nicht bearbeitet werden';
$string['changes'] = '$a Vernderungen';
$string['changesfield'] = 'Zeit seit der letzten nderung in Stunden';
$string['changesfielderror'] = 'Bitte eine korrekte Anzahl Stunden eingeben.';
$string['checklinks'] = 'Links prfen';
$string['checklinkscheck'] = 'Sind Sie sicher, das Sie die Links auf dieser Seite prfen wollen?';
$string['checklinksnotice'] = 'Haben Sie bitte etwas Geduld  bei diesem Vorgang.';
$string['chooseadministration'] = '--- Administration ---';
$string['chooseafile'] = 'Startseite  auswhlen/hochladen';
$string['choosewikilinks'] = '--- Wiki Links auswhlen ----';
$string['comment'] = 'Bemerkung';
$string['contentsize'] = 'Gre';
$string['created'] = 'Erstellt';
$string['deletemewikiword'] = 'Lschen';
$string['deletemewikiwordfound'] = '$a auf dieser Seite gefunden';
$string['deletepage'] = 'Seite lschen';
$string['deleteversions'] = 'Anzahl Versionen zum Lschen';
$string['deleteversionserror'] = 'Bitte eine korrekte Anzahl Versionen eingeben.';
$string['diff'] = 'Unterschiede';
$string['differences'] = 'Unterschiede zwischen Version $a->new_ver und $a->old_ver von $a->pagename';
$string['disablecamel'] = 'KamelHcker-Verlinkung abstellen';
$string['disabledpage'] = 'Diese Seite ist derzeit nicht verfgbar';
$string['doesnotexist'] = 'Diese Seite existiert nicht.  Klicken Sie auf den \'Bearbeiten\'-Button um die Seite zu erstellen.';
$string['downloadaszip'] = 'Downloadbare Zip-Datei';
$string['downloadtimes'] = '$a mal heruntergeladen';
$string['dwnlnofiles'] = 'Bisher wurden keine Dateien hochgeladen';
$string['dwnlsection'] = 'Download-Bereich';
$string['editform1'] = 'Schreiben Sie einfach Ihren Text. Sie knnen ihn einfach spter bearbeiten und gestalten.';
$string['editform2'] = 'Schreiben Sie keine Texte, die andere verrgern knnten. Denken Sie daran, Sie sind hier nicht gnzlich anonym.';
$string['editthispage'] = 'Diese Seite bearbeiten';
$string['emptypage'] = 'Leere Seite';
$string['errorbinandtxt'] = 'Fehler: Seitentyp BIN oder TXT';
$string['errorhtml'] = 'Seitentyp HTML';
$string['errornotype'] = 'Fehler: Seitentyp weder BIN noch TXT';
$string['errororreason'] = 'Fehler oder Grund';
$string['errorroandwr'] = 'Fehler: Seite schreib- und lesbar';
$string['errorsize'] = 'Seite ist grer als 64K';
$string['errversionsave'] = 'Entschuldigung. Whrend Sie Ihren Text bearbeitet haben, hat jemand anders die gleiche Seite aktualisiert. Gehen Sie bitte zum vorherigen Bildschirm zurck, kopieren Sie den Text in die Zwischenablage und fgen Sie die nderungen erneut ein, nachdem Sie die Seite neu geladen haben.';
$string['ewikiacceptbinary'] = 'Binre Dateien zulassen';
$string['ewikiprinttitle'] = 'Den Wikinamen auf jeder Seite anzeigen';
$string['export'] = 'Export';
$string['exportformats'] = 'Exportformate';
$string['exportsuccessful'] = 'Export erfolgreich';
$string['exportto'] = 'Export nach';
$string['fetchback'] = 'Zurck holen';
$string['file'] = 'Datei';
$string['filedownload'] = 'Download von Dateien';
$string['fileisoftype'] = 'Dateiart';
$string['filtername'] = 'Automatische verlinkung von Wikiseiten ';
$string['flagbin'] = 'BIN';
$string['flaghtm'] = 'HTM';
$string['flagoff'] = 'OFF';
$string['flagro'] = 'RO';
$string['flags'] = 'Markierung';
$string['flagsset'] = 'Markierung verndert';
$string['flagtxt'] = 'TXT';
$string['flagwr'] = 'WR';
$string['for'] = 'fr';
$string['forbidden'] = 'Sie sind nicht berechtigt, diese Seite zu bearbeiten.';
$string['groups'] = 'Gruppen';
$string['hits'] = '$a Zugriffe';
$string['howtooperate'] = 'Wie Sie Seiten bearbeiten knnen';
$string['howtowiki'] = 'Wie Sie Wikis bearbeiten';
$string['html'] = 'HTML-Format';
$string['htmlmode'] = 'HTML-Modus';
$string['htmlonly'] = 'nur HTML';
$string['index'] = 'Index';
$string['infoaboutpage'] = 'Informationen ber die Seite';
$string['initialcontent'] = 'Einfhrende Wiki Texte';
$string['invalidroot'] = 'Die Sitemap kann nicht erstellt werden, weil Sie nicht berechtigt diese Seite zu bearbeiten';
$string['lastchanged'] = 'Letzte Bearbeitung am $a';
$string['lastmodified'] = 'Letzte Vernderung';
$string['linkdead'] = 'Gescheitert';
$string['linkok'] = 'OK';
$string['linkschecked'] = 'Links geprft';
$string['listall'] = 'Alle auflisten';
$string['listcandidates'] = 'Kandidaten anzeigen';
$string['meta'] = 'Metadaten';
$string['moduledirectory'] = 'Modulverzeichnis';
$string['modulename'] = 'Wiki';
$string['modulenameplural'] = 'Wikis';
$string['mostoftenchangedpages'] = 'Meist vernderte Seiten';
$string['mostvisitedpages'] = 'Meist besuchte Seiten';
$string['newestpages'] = 'Neueste Seiten';
$string['noadministrationaction'] = 'Keine Administrationsmglichkeit vorhanden';
$string['nocandidatestoremove'] = 'Keine ??? zum entfernen, whlen Sie a, um alle Seiten anzuzeigen.';
$string['nochangestorevert'] = 'Keine Vernderung vorhanden, die rckgngig gemacht werden knnen';
$string['nohtml'] = 'Kein HTML';
$string['nolinksfound'] = 'Keine Links auf der Seite gefunden.';
$string['noregexp'] = 'Die Eingabe muss ein fester Text sein (regulre Ausdrcke oder * knnen nicht verwendet werden). Am besten wird die IP Nummer des Angreifers verwendet, allerdings ohne Portangabe, denn diese ndert mit jedem Seitenzugriff.';
$string['notadministratewiki'] = 'Sie sind nicht berechtigt, dieses Wiki zu administrieren.';
$string['nothingtostrip'] = 'Es gibt keine Seiten mit mehreren Versionen.';
$string['nowikicreated'] = 'In diesem Wiki sind noch keine Seiten bearbeitet worden.';
$string['of'] = 'von';
$string['offline'] = 'OFFLINE';
$string['optional'] = 'Option';
$string['orphanedpage'] = 'Isolierte Seite (keine Verlinkung)';
$string['orphanedpages'] = 'Isolierte Seiten (keine Verlinkungen)';
$string['otherwikis'] = 'Andere Wikis';
$string['ownerunknown'] = 'unbekannt';
$string['pageactions'] = 'Seitenaktivitten';
$string['pageindex'] = 'Seitenindex';
$string['pageinfo'] = 'Seiteninformationen';
$string['pagename'] = 'Seitenname';
$string['pagenamechoice'] = '- oder - ';
$string['pageslinkingto'] = 'Seiten die auf diese Seite verweisen';
$string['pagesremoved'] = 'Gelschte Seiten';
$string['pagesreverted'] = 'Vernderungen rckgngig gemacht.';
$string['pagesstripped'] = 'Herausgenommene Seiten';
$string['plaintext'] = 'Einfacher Text';
$string['preview'] = 'Vorschau';
$string['readonly'] = 'Seite kann nur gelesen werden';
$string['refs'] = 'Referenzen';
$string['removenotice'] = 'Anmerkung: hier werden nur Seiten aufgelistet fr die keine Referenzen vorliegen. Die bersicht ist evtl. unvollstndig.';
$string['removepagecheck'] = 'Sind Sie sicher, dass Sie diese Seiten lschen wollen?';
$string['removepages'] = 'Entfernte Seiten';
$string['removeselectedpages'] = 'Ausgewhlte Seiten entfernen';
$string['revertallsince'] = 'Versionsvergleich mit spteren Vernderungen';
$string['revertchanges'] = 'Vernderungen rckgngig machen';
$string['revertlastonly'] = 'Nur die letzte Vernderung';
$string['revertpages'] = 'Massenvernderungen rckgngig machen';
$string['revertpagescheck'] = 'Wollen Sie diese Vernderunegn wirklich rckgngig machen:';
$string['revertthe'] = 'In die Tiefe der Seitenversionen gehen und nur die vernderten lschen';
$string['safehtml'] = 'Sicheres HTML';
$string['save'] = 'Speichern';
$string['searchwiki'] = 'Wiki durchsuchen';
$string['setpageflags'] = 'Seiteneinstellungen setzen';
$string['sitemap'] = 'Sitemap';
$string['smfor'] = 'Sitemap fr';
$string['status'] = 'Status';
$string['strippagecheck'] = 'Sind Sie sicher, dass Sie ltere Versionen dieser Seite entfernen wollen?';
$string['strippages'] = 'Seiten entfernen';
$string['studentadminoptions'] = 'Teilnehmerverwaltungsoption';
$string['submit'] = 'Ausfhren';
$string['tabattachments'] = 'Anhnge';
$string['tabedit'] = 'Bearbeiten';
$string['tabinfo'] = 'Info';
$string['tablinks'] = 'Links';
$string['tabview'] = 'Anzeigen';
$string['thanksforcontribution'] = 'Danke fr Ihre Mitwirkung';
$string['thispageisntlinkedfromanywhereelse'] = 'Diese Seite ist mit keiner anderen Seite verbunden';
$string['updatedpages'] = 'Aktualisierte Seiten';
$string['uplerror'] = 'Es tut uns leid. Irgendetwas hat beim Upload Ihrer Datei nicht funktioniert.';
$string['uplinsect'] = 'Hochladen nach';
$string['uplnewnam'] = 'Unter einem anderen Dateinamen abspeichern';
$string['upload0'] = 'Verwenden Sie dieses Formular, um eine Datei vorlufig ins Wiki einzufgen:';
$string['uploadedon'] = 'Hochgeladen am';
$string['uploadpicturebutton'] = 'Upload';
$string['uplok'] = 'Ihre Datei wurde korrekt hochgeladen.';
$string['version'] = 'Version';
$string['versionrangetoobig'] = 'Sie knnen nicht alle Versionen dieser Datei lschen! Die letzte Version muss erhalten bleiben.';
$string['versions'] = 'Versionen';
$string['versionstodelete'] = 'Version(en) zum lschen';
$string['viewpage'] = 'Seite anzeigen';
$string['viewsmfor'] = 'Sitemap anzeigen fr';
$string['wantedpages'] = 'Gesuchte Seiten';
$string['wikidefaultpagename'] = 'WikiIndex';
$string['wikiexport'] = 'Seitenexport';
$string['wikiexportcomment'] = 'Hier knnen Sie den Export nach Ihren Bedrfnissen einrichten';
$string['wikilinkoptions'] = 'Einstellung der automatischen Verlinkung von Wikis';
$string['wikilinks'] = 'Wiki Links';
$string['wikiname'] = 'Seitenname';
$string['wikistartederror'] = 'Die Einstellungen des Wikis knnen nicht mehr gendert werden.';
$string['wikitype'] = 'Typ';
$string['wikiusage'] = 'Wiki Anleitung';
$string['withbinaries'] = 'Binre Inhalte einbinden';
$string['withvirtualpages'] = 'Wiki-Links einbinden';
$string['wrongversionrange'] = '$a ist kein zulssiger Wert';

?>

==> moodle-1.5-pgsql.tgz: moodle/lang/de/wiki.php <==
<?PHP // $Id$ 
      // wiki.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005041101)


$string['action'] = '--- Aktion ---';
$string['administration'] = 'Administration';
$string['allowremovepages'] = 'Erlaubt das Entfernen von Seiten';
$string['allowrevertchanges'] = 'Erlaubt  das Aufheben einer Menge von nderungen';
$string['allowsetpage'] = 'Erlaubt das Markieren von Seiten';
$string['allowstrippages'] = 'Erlaubt das Zerlegen von Seiten';
$string['attachments'] = 'Seitenergnzungen';
$string['author'] = 'Autor/in';
$string['authorfieldpattern'] = 'Anzeigeoption fr Autor/in ';
$string['authorfieldpatternerror'] = 'Geben Sie bitte eine/n Autor/in an.';
$string['backlinks'] = 'Link zur Herkunftsseite';
$string['binimgtoolarge'] = 'Bilddatei ist zu gro!';
$string['binnoimg'] = 'Dieses Dateiformat kann nicht verarbeitet werden!';
$string['browse'] = 'Durchsuchen';
$string['canceledit'] = 'Abbrechen';
$string['cannotchangepage'] = 'Diese Seite kann nicht bearbeitet werden';
$string['changes'] = '$a Vernderungen';
$string['changesfield'] = 'Zeit seit der letzten nderung in Stunden';
$string['changesfielderror'] = 'Bitte eine korrekte Anzahl Stunden eingeben.';
$string['checklinks'] = 'Links prfen';
$string['checklinkscheck'] = 'Sind Sie sicher, dass Sie die Links auf dieser Seite prfen wollen?';
$string['checklinksnotice'] = 'Haben Sie bitte etwas Geduld  bei diesem Vorgang.';
$string['chooseadministration'] = '--- Administration ---';
$string['chooseafile'] = 'Startseite  auswhlen/hochladen';
$string['choosewikilinks'] = '--- Wiki Links auswhlen ----';
$string['comment'] = 'Bemerkung';
$string['contentsize'] = 'Gre';
$string['created'] = 'Erstellt';
$string['deletemewikiword'] = 'Lschen';
$string['deletemewikiwordfound'] = '$a auf dieser Seite gefunden';
$string['deletepage'] = 'Seite lschen';
$string['deleteversions'] = 'Anzahl Versionen zum Lschen';
$string['deleteversionserror'] = 'Bitte eine korrekte Anzahl Versionen eingeben.';
$string['diff'] = 'Unterschiede';
$string['differences'] = 'Unterschiede zwischen Version $a->new_ver und $a->old_ver von $a->pagename';
$string['disablecamel'] = 'KamelHcker (CamelCase)-Verlinkung abstellen';
$string['disabledpage'] = 'Diese Seite ist derzeit nicht verfgbar';
$string['doesnotexist'] = 'Diese Seite existiert nicht.  Klicken Sie auf den \'Bearbeiten\'-Button um die Seite zu erstellen.';
$string['downloadaszip'] = 'Downloadbare Zip-Datei';
$string['downloadtimes'] = '$a mal heruntergeladen';
$string['dwnlnofiles'] = 'Bisher wurden keine Dateien hochgeladen';
$string['dwnlsection'] = 'Download-Bereich';
$string['editform1'] = 'Schreiben Sie einfach Ihren Text. Sie knnen ihn einfach spter bearbeiten und gestalten.';
$string['editform2'] = 'Schreiben Sie keine Texte, die andere verrgern knnten. Denken Sie daran, Sie sind hier nicht gnzlich anonym.';
$string['editthispage'] = 'Diese Seite bearbeiten';
$string['emptypage'] = 'Leere Seite';
$string['errorbinandtxt'] = 'Fehler: Seitentyp BIN oder TXT';
$string['errorhtml'] = 'Seitentyp HTML';
$string['errornotype'] = 'Fehler: Seitentyp weder BIN noch TXT';
$string['errororreason'] = 'Fehler oder Grund';
$string['errorroandwr'] = 'Fehler: Seite schreib- und lesbar';
$string['errorsize'] = 'Seite ist grer als 64K';
$string['errversionsave'] = 'Entschuldigung. Whrend Sie Ihren Text bearbeitet haben, hat jemand anders die gleiche Seite aktualisiert. Gehen Sie bitte zum vorherigen Bildschirm zurck, kopieren Sie den Text in die Zwischenablage und fgen Sie die nderungen erneut ein, nachdem Sie die Seite neu geladen haben. Beachten Sie bitte auch die inzwischen vorgenommenen nderungen.';
$string['ewikiacceptbinary'] = 'Binre Dateien zulassen';
$string['ewikiprinttitle'] = 'Den Wikinamen auf jeder Seite anzeigen';
$string['export'] = 'Export';
$string['exportformats'] = 'Exportformate';
$string['exportsuccessful'] = 'Export erfolgreich';
$string['exportto'] = 'Export nach';
$string['fetchback'] = 'Zurck holen';
$string['file'] = 'Datei';
$string['filedownload'] = 'Download von Dateien';
$string['fileisoftype'] = 'Dateiart';
$string['filtername'] = 'Automatische Verlinkung von Wikiseiten ';
$string['flagbin'] = 'BIN';
$string['flaghtm'] = 'HTM';
$string['flagoff'] = 'OFF';
$string['flagro'] = 'RO';
$string['flags'] = 'Markierung';
$string['flagsset'] = 'Markierung verndert';
$string['flagtxt'] = 'TXT';
$string['flagwr'] = 'WR';
$string['for'] = 'fr';
$string['forbidden'] = 'Sie sind nicht berechtigt, diese Seite zu bearbeiten.';
$string['groups'] = 'Gruppen';
$string['hits'] = '$a Zugriffe';
$string['howtooperate'] = 'Wie Sie Seiten bearbeiten knnen';
$string['howtowiki'] = 'Wie Sie Wikis bearbeiten';
$string['html'] = 'HTML-Format';
$string['htmlmode'] = 'HTML-Modus';
$string['htmlonly'] = 'WYSIWIG-Editor';
$string['index'] = 'Index';
$string['infoaboutpage'] = 'Informationen ber die Seite';
$string['initialcontent'] = 'Einfhrende Wiki Texte';
$string['invalidroot'] = 'Die Sitemap kann nicht erstellt werden, weil Sie nicht berechtigt diese Seite zu bearbeiten';
$string['lastchanged'] = 'Letzte Bearbeitung am $a';
$string['lastmodified'] = 'Letzte Vernderung';
$string['linkdead'] = 'Gescheitert';
$string['linkok'] = 'OK';
$string['linkschecked'] = 'Links geprft';
$string['listall'] = 'Alle auflisten';
$string['listcandidates'] = 'Kandidaten anzeigen';
$string['meta'] = 'Metadaten';
$string['moduledirectory'] = 'Modulverzeichnis';
$string['modulename'] = 'Wiki';
$string['modulenameplural'] = 'Wikis';
$string['mostoftenchangedpages'] = 'Meist vernderte Seiten';
$string['mostvisitedpages'] = 'Meist besuchte Seiten';
$string['newestpages'] = 'Neueste Seiten';
$string['noadministrationaction'] = 'Keine Administrationsmglichkeit vorhanden';
$string['nocandidatestoremove'] = 'Keine Seiten zum Entfernen vorhanden, whlen Sie a, um alle Seiten anzuzeigen.';
$string['nochangestorevert'] = 'Keine Vernderung vorhanden, die rckgngig gemacht werden knnen';
$string['nohtml'] = 'Kein HTML';
$string['nolinksfound'] = 'Keine Links auf der Seite gefunden.';
$string['noregexp'] = 'Die Eingabe muss ein fester Text sein (regulre Ausdrcke oder * knnen nicht verwendet werden). Am besten wird die IP Nummer des Angreifers verwendet, allerdings ohne Portangabe, denn diese ndert mit jedem Seitenzugriff.';
$string['notadministratewiki'] = 'Sie sind nicht berechtigt, dieses Wiki zu administrieren.';
$string['nothingtostrip'] = 'Es gibt keine Seiten mit mehreren Versionen.';
$string['nowikicreated'] = 'In diesem Wiki sind noch keine Seiten bearbeitet worden.';
$string['of'] = 'von';
$string['offline'] = 'OFFLINE';
$string['optional'] = 'Option';
$string['orphanedpage'] = 'Isolierte Seite (keine Verlinkung)';
$string['orphanedpages'] = 'Isolierte Seiten (keine Verlinkungen)';
$string['otherwikis'] = 'Andere Wikis';
$string['ownerunknown'] = 'unbekannt';
$string['pageactions'] = 'Seitenaktivitten';
$string['pageindex'] = 'Seitenindex';
$string['pageinfo'] = 'Seiteninformationen';
$string['pagename'] = 'Seitenname';
$string['pagenamechoice'] = '- oder - ';
$string['pageslinkingto'] = 'Seiten die auf diese Seite verweisen';
$string['pagesremoved'] = 'Gelschte Seiten';
$string['pagesreverted'] = 'Vernderungen rckgngig gemacht.';
$string['pagesstripped'] = 'Herausgenommene Seiten';
$string['plaintext'] = 'Einfacher Text';
$string['preview'] = 'Vorschau';
$string['readonly'] = 'Seite kann nur gelesen werden';
$string['refs'] = 'Referenzen';
$string['removenotice'] = 'Anmerkung: hier werden nur Seiten aufgelistet fr die keine Referenzen vorliegen. Die bersicht ist evtl. unvollstndig.';
$string['removepagecheck'] = 'Sind Sie sicher, dass Sie diese Seiten lschen wollen?';
$string['removepages'] = 'Entfernte Seiten';
$string['removeselectedpages'] = 'Ausgewhlte Seiten entfernen';
$string['revertallsince'] = 'Versionsvergleich mit spteren Vernderungen';
$string['revertchanges'] = 'Vernderungen rckgngig machen';
$string['revertlastonly'] = 'Nur die letzte Vernderung';
$string['revertpages'] = 'Mehrere Vernderungen rckgngig machen';
$string['revertpagescheck'] = 'Wollen Sie diese Vernderunegn wirklich rckgngig machen?';
$string['revertthe'] = 'In die Tiefe der Seitenversionen gehen und nur die Vernderten lschen';
$string['safehtml'] = 'Sicheres HTML';
$string['save'] = 'Speichern';
$string['searchwiki'] = 'Wiki durchsuchen';
$string['setpageflags'] = 'Seiteneinstellungen setzen';
$string['sitemap'] = 'Sitemap';
$string['smfor'] = 'Sitemap fr';
$string['status'] = 'Status';
$string['strippagecheck'] = 'Sind Sie sicher, dass Sie ltere Versionen dieser Seite entfernen wollen?';
$string['strippages'] = 'Seiten entfernen';
$string['studentadminoptions'] = 'Teilnehmerverwaltungsoption';
$string['submit'] = 'Ausfhren';
$string['tabattachments'] = 'Anhnge';
$string['tabedit'] = 'Bearbeiten';
$string['tabinfo'] = 'Info';
$string['tablinks'] = 'Links';
$string['tabview'] = 'Anzeigen';
$string['thanksforcontribution'] = 'Danke fr Ihre Mitwirkung';
$string['thispageisntlinkedfromanywhereelse'] = 'Diese Seite ist mit keiner anderen Seite verbunden';
$string['updatedpages'] = 'Aktualisierte Seiten';
$string['updatedwikipages'] = 'Aktualisierte Wikiseiten';
$string['uplerror'] = 'Es tut uns leid. Irgend etwas hat beim Upload Ihrer Datei nicht funktioniert.';
$string['uplinsect'] = 'Hochladen nach';
$string['uplnewnam'] = 'Unter einem anderen Dateinamen abspeichern';
$string['upload0'] = 'Verwenden Sie dieses Formular, um eine Datei vorlufig ins Wiki einzufgen:';
$string['uploadedon'] = 'Hochgeladen am';
$string['uploadpicturebutton'] = 'Upload';
$string['uplok'] = 'Ihre Datei wurde korrekt hochgeladen.';
$string['version'] = 'Version';
$string['versionrangetoobig'] = 'Sie knnen nicht alle Versionen dieser Datei lschen! Die letzte Version mu erhalten bleiben.';
$string['versions'] = 'Versionen';
$string['versionstodelete'] = 'Version(en) zum lschen';
$string['viewpage'] = 'Seite anzeigen';
$string['viewsmfor'] = 'Sitemap anzeigen fr';
$string['wantedpages'] = 'Gesuchte Seiten';
$string['wikidefaultpagename'] = 'WikiIndex';
$string['wikiexport'] = 'Seitenexport';
$string['wikiexportcomment'] = 'Hier knnen Sie den Export nach Ihren Bedrfnissen einrichten';
$string['wikilinkoptions'] = 'Einstellung der automatischen Verlinkung von Wikis';
$string['wikilinks'] = 'Wiki Links';
$string['wikiname'] = 'Seitenname';
$string['wikistartederror'] = 'Im Wiki wurden bereits Daten eingetragen. Die Einstellungen des Wikis knnen nicht mehr gendert werden.';
$string['wikitype'] = 'Typ';
$string['wikiusage'] = 'Wiki Anleitung';
$string['withbinaries'] = 'Binre Inhalte einbinden';
$string['withvirtualpages'] = 'Wiki-Links einbinden';
$string['wrongversionrange'] = '$a ist kein zulssiger Wert';

?>
